@@ -304,9 +304,16 @@ create_transfer_dialog (const GnomeVFSXferProgressInfo *progress_info,
 
 	/* Make the progress dialog show up over the window we are copying into */
 	if (transfer_info->parent_view != NULL) {
-		gtk_window_set_transient_for (
-			GTK_WINDOW (transfer_info->progress_dialog), 
-			GTK_WINDOW (gtk_widget_get_toplevel (transfer_info->parent_view)));
+		GtkWidget *toplevel;
+
+		/* Transient-for-desktop are visible on all desktops, we don't want
+		   that. */
+		toplevel = gtk_widget_get_toplevel (transfer_info->parent_view);
+		if (toplevel != NULL &&
+		    g_object_get_data (G_OBJECT (toplevel), "is_desktop_window") == NULL) {
+			gtk_window_set_transient_for (GTK_WINDOW (transfer_info->progress_dialog), 
+						      GTK_WINDOW (toplevel));
+		}
 	}
 }
 
@@ -601,7 +608,7 @@ build_error_string (const char *source_name, const char *target_name,
 						  "permissions to change it or its parent folder.");
 				break;
 			case ERROR_SOURCE_IN_TARGET:
-				*error_string = g_strdup (_("Error while moving. "));
+				*error_string = g_strdup (_("Error while moving."));
 				detail_format = _("Cannot move \"%s\" because it or its parent folder "
 						  "are contained in the destination.");
 				break;
@@ -1008,12 +1015,36 @@ is_special_link (const char *uri)
 	return eel_uri_is_desktop (uri);
 }
 
+static gboolean
+is_directory (const char *uri)
+{
+	GnomeVFSFileInfo *info;
+	GnomeVFSResult result;
+	gboolean is_dir;
+
+	is_dir = FALSE;
+	
+	info = gnome_vfs_file_info_new ();
+	result = gnome_vfs_get_file_info (uri, info, GNOME_VFS_FILE_INFO_DEFAULT);
+
+	if (result == GNOME_VFS_OK &&
+	    info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_TYPE) {
+		is_dir = (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY);
+	}
+	
+	gnome_vfs_file_info_unref (info);
+
+	return is_dir;
+}
+
+
 static int
 handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 		           TransferInfo *transfer_info)
 {
 	int result;
 	char *text, *primary_text, *secondary_text, *formatted_name;
+	gboolean is_merge, target_is_dir;
 
 	nautilus_file_operations_progress_pause_timeout (transfer_info->progress_dialog);	
 
@@ -1053,10 +1084,25 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 	/* transfer conflict, prompt the user to replace or skip */
 	formatted_name = format_and_ellipsize_uri_for_dialog (
 		parent_for_error_dialog (transfer_info), progress_info->target_name);
-	text = g_strdup_printf (_("The file \"%s\" already exists.  Would you like to replace it?"), 
-	                        formatted_name);
+
+	target_is_dir = is_directory (progress_info->target_name);
+	if (target_is_dir) {
+		text = g_strdup_printf (_("The folder \"%s\" already exists.  Would you like to replace it?"), 
+					formatted_name);
+	} else {
+		text = g_strdup_printf (_("The file \"%s\" already exists.  Would you like to replace it?"), 
+					formatted_name);
+	}
 	g_free (formatted_name);
 
+	is_merge =  target_is_dir && is_directory (progress_info->source_name);
+
+	if (is_merge) {
+		secondary_text = _("If you replace the existing folder, any files in it that conflicts with the files being copied will be overwritten.");
+	} else {
+		secondary_text = _("If you replace an existing file, its contents will be overwritten.");
+	}
+	
 	if (progress_info->duplicate_count == 1) {
 		/* we are going to only get one duplicate alert, don't offer
 		 * Replace All
@@ -1066,7 +1112,7 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 			 TRUE,
 			 GTK_MESSAGE_QUESTION, 
 			 text, 
-			 _("If you replace an existing file, its contents will be overwritten."), 
+			 secondary_text, 
 			 _("Conflict While Copying"),
 			 _("_Skip"), _("_Replace"), NULL);
 		g_free (text);	 
@@ -1085,7 +1131,7 @@ handle_transfer_overwrite (const GnomeVFSXferProgressInfo *progress_info,
 	} else {
 		result = eel_run_simple_dialog
 			(parent_for_error_dialog (transfer_info), TRUE, GTK_MESSAGE_QUESTION, text, 
-			 _("If you replace an existing file, its contents will be overwritten."),  
+			 secondary_text, 
 			 _("Conflict While Copying"),
 			 _("Replace _All"), _("_Skip"), _("_Replace"), NULL);
 		g_free (text);
@@ -1484,8 +1530,19 @@ get_next_duplicate_name (char *name, int count_increment)
 
 	unescaped_name = g_filename_to_utf8 (unescaped_tmp_name, -1,
 					     NULL, NULL, NULL);
-	g_free (unescaped_tmp_name);
+	if (!unescaped_name) {
+		/* Couldn't convert to utf8 - probably
+		 * G_BROKEN_FILENAMES not set when it should be.
+		 * Try converting from the locale */
+		unescaped_name = g_locale_to_utf8 (unescaped_tmp_name, -1, NULL, NULL, NULL);	
 
+		if (!unescaped_name) {
+			unescaped_name = eel_make_valid_utf8 (unescaped_tmp_name);
+		}
+	}
+		
+	g_free (unescaped_tmp_name);
+	
 	unescaped_result = get_duplicate_name (unescaped_name, count_increment);
 	g_free (unescaped_name);
 
@@ -2484,28 +2541,34 @@ static gboolean
 confirm_empty_trash (GtkWidget *parent_view)
 {
 	GtkWidget *dialog;
-	GtkWindow *parent_window;
 	int response;
 	GtkWidget *hbox, *vbox, *image, *label, *button;
 	gchar     *str;
+	GdkScreen *screen;
 
 	/* Just Say Yes if the preference says not to confirm. */
 	if (!eel_preferences_get_boolean (NAUTILUS_PREFERENCES_CONFIRM_TRASH)) {
 		return TRUE;
 	}
 	
-	parent_window = GTK_WINDOW (gtk_widget_get_toplevel (parent_view));
+	screen = gtk_widget_get_screen (parent_view);
 
 	dialog = gtk_dialog_new ();
+	gtk_window_set_screen (GTK_WINDOW (dialog), screen);
+	atk_object_set_role (gtk_widget_get_accessible (dialog), ATK_ROLE_ALERT);
 	gtk_window_set_title (GTK_WINDOW (dialog), "");
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 	gtk_window_set_wmclass (GTK_WINDOW (dialog), "empty_trash",
 				"Nautilus");
-	gtk_window_set_transient_for (GTK_WINDOW (dialog),
-				      GTK_WINDOW (parent_window));
 
+	/* Make transient for the window group */
+        gtk_widget_realize (dialog);
+	gdk_window_set_transient_for (GTK_WIDGET (dialog)->window,
+				      gdk_screen_get_root_window (screen));
+	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+	
 	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 14);
 
 	hbox = gtk_hbox_new (FALSE, 12);
