@@ -53,7 +53,6 @@ static void     global_preferences_install_defaults      (void);
 static void     global_preferences_register_enumerations (void);
 static gpointer default_font_callback                    (void);
 static gpointer default_home_location_callback           (void);
-static gpointer default_default_folder_viewer_callback	 (void);
 static void     import_old_preferences_if_needed         (void);
 static gpointer default_home_link_name                   (void);
 static gpointer default_computer_link_name               (void);
@@ -408,6 +407,10 @@ static const PreferenceDefault preference_defaults[] = {
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
 	},
+	{ NAUTILUS_PREFERENCES_NAVIGATION_WINDOW_SAVED_GEOMETRY,
+	  PREFERENCE_STRING,
+	  ""
+	},
 	{ NAUTILUS_PREFERENCES_TREE_SHOW_ONLY_DIRECTORIES,
 	  PREFERENCE_BOOLEAN,
 	  GINT_TO_POINTER (TRUE)
@@ -418,7 +421,12 @@ static const PreferenceDefault preference_defaults[] = {
 	  NULL, NULL,
 	  "date_format"
 	},
-
+	{ NAUTILUS_PREFERENCES_DEFAULT_FOLDER_VIEWER,
+	  PREFERENCE_INTEGER,
+	  GINT_TO_POINTER (NAUTILUS_DEFAULT_FOLDER_VIEWER_ICON_VIEW),
+	  NULL, NULL,
+	  "default_folder_viewer"
+	},
 	/* Home URI */
 	{ NAUTILUS_PREFERENCES_HOME_URI,
 	  PREFERENCE_STRING,
@@ -658,97 +666,31 @@ default_font_callback (void)
 	return g_strdup ("sans 12");
 }
 
-static int
-get_default_folder_viewer_preference_from_iid (const char *iid)
-{
-	g_return_val_if_fail (iid != NULL, NAUTILUS_DEFAULT_FOLDER_VIEWER_ICON_VIEW);
-
-	if (strcmp (iid, NAUTILUS_LIST_VIEW_IID) == 0) {
-		return NAUTILUS_DEFAULT_FOLDER_VIEWER_LIST_VIEW;
-	} else if (strcmp (iid, NAUTILUS_ICON_VIEW_IID) == 0) {
-		return NAUTILUS_DEFAULT_FOLDER_VIEWER_ICON_VIEW;
-	}
-
-	return NAUTILUS_DEFAULT_FOLDER_VIEWER_OTHER;
-}
-
-static gpointer
-default_default_folder_viewer_callback (void)
-{
-	Bonobo_ServerInfo *bonobo_activation_info;
-	int result;
-
-	bonobo_activation_info = gnome_vfs_mime_get_default_component ("x-directory/normal");
-	if (bonobo_activation_info == NULL) {
-		result = NAUTILUS_DEFAULT_FOLDER_VIEWER_ICON_VIEW;
-	} else {
-		result = get_default_folder_viewer_preference_from_iid (bonobo_activation_info->iid);
-		if (result == NAUTILUS_DEFAULT_FOLDER_VIEWER_OTHER) {
-			result = NAUTILUS_DEFAULT_FOLDER_VIEWER_ICON_VIEW;
-		}
-		CORBA_free (bonobo_activation_info);
-	}
-
-	return GINT_TO_POINTER (result);
-}
-
 static gpointer
 default_home_location_callback (void)
 {
 	return gnome_vfs_get_uri_from_local_path (g_get_home_dir ());
 }
 
-static void
-set_default_folder_viewer_in_gnome_vfs (const char *iid)
-{
-	gnome_vfs_mime_set_default_action_type ("x-directory/normal", GNOME_VFS_MIME_ACTION_TYPE_COMPONENT);
-	gnome_vfs_mime_set_default_component ("x-directory/normal", iid);
-}
-
-/* Convert between gnome-vfs and gconf ways of storing this information. */
-static void
-default_folder_viewer_changed_callback (gpointer callback_data)
+/*
+ * Public functions
+ */
+char *
+nautilus_global_preferences_get_default_folder_viewer_preference_as_iid (void)
 {
 	int preference_value;
 	const char *viewer_iid;
 
-	g_assert (callback_data == NULL);
-
 	preference_value = 
 		eel_preferences_get_enum (NAUTILUS_PREFERENCES_DEFAULT_FOLDER_VIEWER);
 
 	if (preference_value == NAUTILUS_DEFAULT_FOLDER_VIEWER_LIST_VIEW) {
 		viewer_iid = NAUTILUS_LIST_VIEW_IID;
 	} else {
-		g_return_if_fail (preference_value == NAUTILUS_DEFAULT_FOLDER_VIEWER_ICON_VIEW);
 		viewer_iid = NAUTILUS_ICON_VIEW_IID;
 	}
 
-	set_default_folder_viewer_in_gnome_vfs (viewer_iid);
-}
-
-/*
- * Public functions
- */
-
-void
-nautilus_global_preferences_set_default_folder_viewer (const char *iid)
-{
-	int viewer_preference;
-
-	set_default_folder_viewer_in_gnome_vfs (iid);
-
-	viewer_preference = get_default_folder_viewer_preference_from_iid (iid);
-
-	/* If viewer is set to one that the Preferences dialog doesn't know about,
-	 * just change the underlying gnome-vfs setting but leave the Preferences dialog alone.
-	 */
-	if (viewer_preference == NAUTILUS_DEFAULT_FOLDER_VIEWER_OTHER) {
-		return;		
-	}
-	
-	eel_preferences_set_enum (NAUTILUS_PREFERENCES_DEFAULT_FOLDER_VIEWER,
-				  viewer_preference);
+	return g_strdup (viewer_iid);
 }
 
 /* The icon view uses 2 variables to store the sort order and
@@ -857,33 +799,3 @@ nautilus_global_preferences_init (void)
 	eel_gconf_preload_cache ("/apps/nautilus/preferences",
 				 GCONF_CLIENT_PRELOAD_ONELEVEL);
 }
-
-void
-nautilus_global_preferences_init_with_folder_browsing (void)
-{
-	static gboolean browse_initialized = FALSE;
-	static const PreferenceDefault browse_default = {
-		NAUTILUS_PREFERENCES_DEFAULT_FOLDER_VIEWER,
-		PREFERENCE_INTEGER,
-		NULL, default_default_folder_viewer_callback, NULL,
-		"default_folder_viewer"
-	};
-
-	nautilus_global_preferences_init ();
-
-	if (browse_initialized) {
-		return;
-	}
-	browse_initialized = TRUE;
-
-	eel_preferences_set_enumeration_id (browse_default.name,
-					    browse_default.enumeration_id);
-	
-	global_preferences_install_one_default (browse_default.name,
-						browse_default.type,
-						&browse_default);
-
-	eel_preferences_add_callback (NAUTILUS_PREFERENCES_DEFAULT_FOLDER_VIEWER, 
-				      default_folder_viewer_changed_callback, 
-				      NULL);	
-}
