@@ -28,6 +28,7 @@
 
 
 #include <config.h>
+#include <math.h>
 #include "nautilus-icon-dnd.h"
 
 #include "nautilus-file-dnd.h"
@@ -56,7 +57,7 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <math.h>
+#include <libnautilus-private/nautilus-file-utilities.h>
 #include <stdio.h>
 #include <string.h>
 
@@ -78,6 +79,8 @@ static GtkTargetEntry drop_types [] = {
 	/* Must be last: */
 	{ NAUTILUS_ICON_DND_ROOTWINDOW_DROP_TYPE,  0, NAUTILUS_ICON_DND_ROOTWINDOW_DROP }
 };
+static void     stop_dnd_highlight         (GtkWidget      *widget);
+static void     dnd_highlight_queue_redraw (GtkWidget      *widget);
 
 static GtkTargetList *drop_types_list = NULL;
 static GtkTargetList *drop_types_list_root = NULL;
@@ -513,6 +516,8 @@ nautilus_icon_container_selection_items_local (NautilusIconContainer *container,
 		 * would not work for it.
 		 */
 		result = nautilus_drag_items_in_trash (items);
+	} else if (eel_uri_is_desktop (container_uri_string)) {
+		result = nautilus_drag_items_on_desktop (items);
 	} else {
 		result = nautilus_drag_items_local (container_uri_string, items);
 	}
@@ -530,12 +535,13 @@ get_background_drag_action (NautilusIconContainer *container,
 	GdkDragAction valid_actions;
 
 	if (action == GDK_ACTION_ASK) {
-		valid_actions = NAUTILUS_DND_ACTION_SET_AS_BACKGROUND;
+		valid_actions = NAUTILUS_DND_ACTION_SET_AS_FOLDER_BACKGROUND;
 		if (g_object_get_data (G_OBJECT (eel_get_widget_background (GTK_WIDGET (container))), "is_desktop") == 0) {
 			valid_actions |= NAUTILUS_DND_ACTION_SET_AS_GLOBAL_BACKGROUND;
 		}
 
-		action = nautilus_drag_drop_background_ask (valid_actions);
+		action = nautilus_drag_drop_background_ask 
+			(GTK_WIDGET (container), valid_actions);
 	}
 
 	return action;
@@ -649,6 +655,9 @@ auto_scroll_timeout_callback (gpointer data)
 		return TRUE;
 	}
 
+	/* Clear the old dnd highlight frame */
+	dnd_highlight_queue_redraw (widget);
+	
 	if (!nautilus_icon_container_scroll (container, (int)x_scroll_delta, (int)y_scroll_delta)) {
 		/* the scroll value got pinned to a min or max adjustment value,
 		 * we ended up not scrolling
@@ -656,6 +665,9 @@ auto_scroll_timeout_callback (gpointer data)
 		return TRUE;
 	}
 
+	/* Make sure the dnd highlight frame is redrawn */
+	dnd_highlight_queue_redraw (widget);
+	
 	/* update cached drag start offsets */
 	container->details->dnd_info->drag_info.start_x -= x_scroll_delta;
 	container->details->dnd_info->drag_info.start_y -= y_scroll_delta;
@@ -712,7 +724,9 @@ stop_auto_scroll (NautilusIconContainer *container)
 static gboolean
 confirm_switch_to_manual_layout (NautilusIconContainer *container)
 {
+#if 0
 	const char *message;
+	const char *detail;
 	GtkDialog *dialog;
 	int response;
 
@@ -723,33 +737,36 @@ confirm_switch_to_manual_layout (NautilusIconContainer *container)
 	 */
 	if (nautilus_icon_container_has_stored_icon_positions (container)) {
 		if (eel_g_list_exactly_one_item (container->details->dnd_info->drag_info.selection_list)) {
-			message = _("This folder uses automatic layout. "
-			"Do you want to switch to manual layout and leave this item where you dropped it? "
+			message = _("Do you want to switch to manual layout and leave this item where you dropped it? "
 			"This will clobber the stored manual layout.");
+			detail = _("This folder uses automatic layout.");
 		} else {
-			message = _("This folder uses automatic layout. "
-			"Do you want to switch to manual layout and leave these items where you dropped them? "
+			message = _("Do you want to switch to manual layout and leave these items where you dropped them? "
 			"This will clobber the stored manual layout.");
+			detail = _("This folder uses automatic layout.");
 		}
 	} else {
 		if (eel_g_list_exactly_one_item (container->details->dnd_info->drag_info.selection_list)) {
-			message = _("This folder uses automatic layout. "
-			"Do you want to switch to manual layout and leave this item where you dropped it?");
+			message = _("Do you want to switch to manual layout and leave this item where you dropped it?");
+			detail = _("This folder uses automatic layout.");
 		} else {
-			message = _("This folder uses automatic layout. "
-			"Do you want to switch to manual layout and leave these items where you dropped them?");
+			message = _("Do you want to switch to manual layout and leave these items where you dropped them?");
+			detail = _("This folder uses automatic layout.");
+
 		}
 	}
 
-	dialog = eel_show_yes_no_dialog (message, _("Switch to Manual Layout?"),
+	dialog = eel_show_yes_no_dialog (message, detail, _("Switch to Manual Layout?"),
 					 _("Switch"), GTK_STOCK_CANCEL,
-					 GTK_WINDOW (gtk_widget_get_ancestor 
-						     (GTK_WIDGET (container), GTK_TYPE_WINDOW)));
-	
+					 GTK_WINDOW (gtk_widget_get_toplevel(GTK_WIDGET(container))));
+
 	response = gtk_dialog_run (dialog);
 	gtk_object_destroy (GTK_OBJECT (dialog));
 
 	return response == GTK_RESPONSE_YES;
+#else
+	return FALSE;
+#endif
 }
 
 static void
@@ -807,7 +824,7 @@ handle_local_move (NautilusIconContainer *container,
 				(container, icon,
 				 world_x + item->icon_x, world_y + item->icon_y,
 				 icon->scale_x, icon->scale_y,
-				 TRUE, TRUE);
+				 TRUE, TRUE, TRUE);
 		}
 		moved_icons = g_list_prepend (moved_icons, icon);
 	}		
@@ -827,6 +844,7 @@ handle_nonlocal_move (NautilusIconContainer *container,
 {
 	GList *source_uris, *p;
 	GArray *source_item_locations;
+	gboolean free_target_uri;
 	int index;
 
 	if (container->details->dnd_info->drag_info.selection_list == NULL) {
@@ -856,7 +874,14 @@ handle_nonlocal_move (NautilusIconContainer *container,
 				((NautilusDragSelectionItem *)p->data)->icon_y;
 		}
 	}
-		
+
+	free_target_uri = FALSE;
+ 	/* Rewrite internal desktop URIs to the normal target uri */
+	if (eel_uri_is_desktop (target_uri)) {
+		target_uri = nautilus_get_desktop_directory_uri ();
+		free_target_uri = TRUE;
+	}
+	
 	/* start the copy */
 	g_signal_emit_by_name (container, "move_copy_items",
 				 source_uris,
@@ -865,6 +890,10 @@ handle_nonlocal_move (NautilusIconContainer *container,
 				 context->action,
 				 x, y);
 
+	if (free_target_uri) {
+		g_free ((char *)target_uri);
+	}
+
 	g_list_free (source_uris);
 	g_array_free (source_item_locations, TRUE);
 }
@@ -939,8 +968,7 @@ selection_is_image_file (GList *selection_list)
 
 	mime_type = gnome_vfs_get_mime_type (selected_item->uri);
 
-	result = (g_ascii_strcasecmp (mime_type, "image/svg") != 0 &&
-		  eel_istr_has_prefix (mime_type, "image/"));
+	result = eel_istr_has_prefix (mime_type, "image/");
 	
 	g_free (mime_type);
 	
@@ -979,7 +1007,8 @@ nautilus_icon_container_receive_dropped_icons (NautilusIconContainer *container,
 				action |= NAUTILUS_DND_ACTION_SET_AS_BACKGROUND;
 			}
 		}
-		context->action = nautilus_drag_drop_action_ask (action);
+		context->action = nautilus_drag_drop_action_ask
+			(GTK_WIDGET (container), action);
 	}
 	
 	if (context->action == NAUTILUS_DND_ACTION_SET_AS_BACKGROUND) {
@@ -1117,6 +1146,7 @@ nautilus_icon_dnd_update_drop_target (NautilusIconContainer *container,
 	NautilusIcon *icon;
 	NautilusFile *file;
 	double world_x, world_y;
+	char *uri;
 	
 	g_assert (NAUTILUS_IS_ICON_CONTAINER (container));
 	if ((container->details->dnd_info->drag_info.selection_list == NULL) 
@@ -1137,8 +1167,10 @@ nautilus_icon_dnd_update_drop_target (NautilusIconContainer *container,
 
 	/* Find if target icon accepts our drop. */
 	if (icon != NULL && (container->details->dnd_info->drag_info.data_type != NAUTILUS_ICON_DND_KEYWORD)) {
-		    file = nautilus_file_get (nautilus_icon_container_get_icon_uri (container, icon));
-
+		    uri = nautilus_icon_container_get_icon_uri (container, icon);
+		    file = nautilus_file_get (uri);
+		    g_free (uri);
+		
 		    if (!nautilus_drag_can_accept_items (file,
 							 container->details->dnd_info->drag_info.selection_list)) {
 			    icon = NULL;
@@ -1182,7 +1214,10 @@ drag_leave_callback (GtkWidget *widget,
 	
 	if (dnd_info->shadow != NULL)
 		eel_canvas_item_hide (dnd_info->shadow);
+
+	stop_dnd_highlight (widget);
 	
+	set_drop_target (NAUTILUS_ICON_CONTAINER (widget), NULL);
 	stop_auto_scroll (NAUTILUS_ICON_CONTAINER (widget));
 	nautilus_icon_container_free_drag_data(NAUTILUS_ICON_CONTAINER (widget));
 }
@@ -1191,15 +1226,17 @@ void
 nautilus_icon_dnd_begin_drag (NautilusIconContainer *container,
 			      GdkDragAction actions,
 			      int button,
-			      GdkEventMotion *event)
+			      GdkEventMotion *event,
+			      int                    start_x,
+			      int                    start_y)
 {
 	NautilusIconDndInfo *dnd_info;
 	EelCanvas *canvas;
 	GdkDragContext *context;
-	GdkPixbuf *pixbuf;
+	GdkPixmap *pixmap;
+	GdkBitmap *mask;
 	int x_offset, y_offset;
-	ArtDRect world_rect;
-	ArtIRect widget_rect;
+	double x1, y1, x2, y2, winx, winy;
 	
 	g_return_if_fail (NAUTILUS_IS_ICON_CONTAINER (container));
 	g_return_if_fail (event != NULL);
@@ -1211,25 +1248,22 @@ nautilus_icon_dnd_begin_drag (NautilusIconContainer *container,
            the way the canvas handles events.
 	*/
 	canvas = EEL_CANVAS (container);
-	dnd_info->drag_info.start_x = event->x - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
-	dnd_info->drag_info.start_y = event->y - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));	
+	dnd_info->drag_info.start_x = start_x - gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (canvas)));
+	dnd_info->drag_info.start_y = start_y - gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (canvas)));	
 
         /* create a pixmap and mask to drag with */
-        pixbuf = nautilus_icon_canvas_item_get_image (container->details->drag_icon->item);
+        pixmap = nautilus_icon_canvas_item_get_image (container->details->drag_icon->item, &mask);
     
     	/* we want to drag semi-transparent pixbufs, but X is too slow dealing with
 	   stippled masks, so we had to remove the code; this comment is left as a memorial
 	   to it, with the hope that we get it back someday as X Windows improves */
 	
         /* compute the image's offset */
-	world_rect = nautilus_icon_canvas_item_get_icon_rectangle
-		(container->details->drag_icon->item);
-
-	canvas_rect_world_to_widget (EEL_CANVAS (container),
-				     &world_rect, &widget_rect);
-	
-        x_offset = dnd_info->drag_info.start_x - widget_rect.x0;
-        y_offset = dnd_info->drag_info.start_y - widget_rect.y0;
+	eel_canvas_item_get_bounds (EEL_CANVAS_ITEM (container->details->drag_icon->item),
+				    &x1, &y1, &x2, &y2);
+	eel_canvas_world_to_window (canvas, x1, y1,  &winx, &winy);
+        x_offset = start_x - winx;
+        y_offset = start_y - winy;
         
 	/* start the drag */
 	context = gtk_drag_begin (GTK_WIDGET (container),
@@ -1240,7 +1274,100 @@ nautilus_icon_dnd_begin_drag (NautilusIconContainer *container,
 
 	if (context) {
 		/* set the icon for dragging */
-		gtk_drag_set_icon_pixbuf (context, pixbuf, x_offset, y_offset);
+		gtk_drag_set_icon_pixmap (context,
+					  gtk_widget_get_colormap (GTK_WIDGET (container)),
+					  pixmap, mask,
+					  x_offset, y_offset);
+	}
+}
+
+static gboolean
+drag_highlight_expose (GtkWidget      *widget,
+		       GdkEventExpose *event,
+		       gpointer        data)
+{
+	gint x, y, width, height;
+	GdkWindow *window;
+	
+	x = gtk_adjustment_get_value (gtk_layout_get_hadjustment (GTK_LAYOUT (widget)));
+	y = gtk_adjustment_get_value (gtk_layout_get_vadjustment (GTK_LAYOUT (widget)));
+	gdk_drawable_get_size (widget->window, &width, &height);
+
+	window = GTK_LAYOUT (widget)->bin_window;
+	
+	gtk_paint_shadow (widget->style, window,
+			  GTK_STATE_NORMAL, GTK_SHADOW_OUT,
+			  NULL, widget, "dnd",
+			  x, y, width, height);
+  
+	gdk_draw_rectangle (window,
+			    widget->style->black_gc,
+			    FALSE,
+			    x, y, width - 1, height - 1);
+
+	
+	return FALSE;
+}
+
+/* Queue a redraw of the dnd highlight rect */
+static void
+dnd_highlight_queue_redraw (GtkWidget *widget)
+{
+	NautilusIconDndInfo *dnd_info;
+	int width, height;
+	
+	dnd_info = NAUTILUS_ICON_CONTAINER (widget)->details->dnd_info;
+	
+	if (!dnd_info->highlighted) {
+		return;
+	}
+
+	width = widget->allocation.width;
+	height = widget->allocation.height;
+
+	gtk_widget_queue_draw_area (widget,
+				    0, 0,
+				    width, 1);
+	gtk_widget_queue_draw_area (widget,
+				    0, 0,
+				    1, height);
+	gtk_widget_queue_draw_area (widget,
+				    0, height - 1,
+				    width, 1);
+	gtk_widget_queue_draw_area (widget,
+				    width - 1, 0,
+				    1, height);
+}
+
+static void
+start_dnd_highlight (GtkWidget *widget)
+{
+	NautilusIconDndInfo *dnd_info;
+	
+	dnd_info = NAUTILUS_ICON_CONTAINER (widget)->details->dnd_info;
+
+	if (!dnd_info->highlighted) {
+		dnd_info->highlighted = TRUE;
+		g_signal_connect_after (widget, "expose_event",
+					G_CALLBACK (drag_highlight_expose),
+					NULL);
+		gtk_widget_queue_draw (widget);
+	}
+}
+
+static void
+stop_dnd_highlight (GtkWidget *widget)
+{
+	NautilusIconDndInfo *dnd_info;
+	
+	dnd_info = NAUTILUS_ICON_CONTAINER (widget)->details->dnd_info;
+
+	if (dnd_info->highlighted) {
+		dnd_info->highlighted = FALSE;
+		g_signal_handlers_disconnect_by_func (widget,
+						      drag_highlight_expose,
+						      NULL);
+		gtk_widget_queue_draw (widget);
 	}
 }
 
@@ -1262,6 +1389,10 @@ drag_motion_callback (GtkWidget *widget,
 	action = 0;
 	nautilus_icon_container_get_drop_action (NAUTILUS_ICON_CONTAINER (widget), context, x, y,
 						 &action);
+	if (action != 0) {
+		start_dnd_highlight (widget);
+	}
+	  
 	gdk_drag_status (context, action, time);
 
 	return TRUE;
