@@ -1486,7 +1486,7 @@ remove_file_metadata (NautilusMetafile *metafile,
 			if (found) {
 				g_hash_table_remove (hash, file_name);
 				g_free (key);
-				metadata_value_destroy (value);
+				destroy_metadata_changes_hash_table (value);
 			}
 		}
 	}
@@ -1851,7 +1851,7 @@ directory_request_write_metafile (NautilusMetafile *metafile)
 	if (metafile->details->write_idle_id == 0) {
 		bonobo_object_ref (metafile);
 		metafile->details->write_idle_id =
-			gtk_idle_add (metafile_write_idle_callback, metafile);
+			g_idle_add (metafile_write_idle_callback, metafile);
 	}
 }
 
