@@ -24,13 +24,20 @@
 
 #include <config.h>
 #include "nautilus-desktop-window.h"
+#include "nautilus-window-private.h"
 
 #include <X11/Xatom.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtklayout.h>
+#include <eel/eel-gtk-macros.h>
+#include <eel/eel-vfs-extensions.h>
 #include <libgnome/gnome-macros.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
+#include <libnautilus-private/nautilus-bonobo-extensions.h>
+
+#define STATUS_BAR_PATH         "/status"
+#define MENU_BAR_PATH           "/menu"
 
 struct NautilusDesktopWindowDetails {
 	int dummy;
@@ -39,7 +46,7 @@ struct NautilusDesktopWindowDetails {
 static void set_wmspec_desktop_hint (GdkWindow *window);
 
 GNOME_CLASS_BOILERPLATE (NautilusDesktopWindow, nautilus_desktop_window,
-			 NautilusWindow, NAUTILUS_TYPE_WINDOW)
+			 NautilusSpatialWindow, NAUTILUS_TYPE_SPATIAL_WINDOW)
 
 static void
 nautilus_desktop_window_instance_init (NautilusDesktopWindow *window)
@@ -53,6 +60,9 @@ nautilus_desktop_window_instance_init (NautilusDesktopWindow *window)
 	 */
 	gtk_window_set_resizable (GTK_WINDOW (window),
 				  FALSE);
+
+	g_object_set_data (G_OBJECT (window), "is_desktop_window", 
+			   GINT_TO_POINTER (1));
 }
 
 static gint
@@ -65,18 +75,25 @@ nautilus_desktop_window_delete_event (NautilusDesktopWindow *window)
 void
 nautilus_desktop_window_update_directory (NautilusDesktopWindow *window)
 {
-	char *desktop_directory_path;
-	char *desktop_directory_uri;
-
 	g_assert (NAUTILUS_IS_DESKTOP_WINDOW (window));
-
-	desktop_directory_path = nautilus_get_desktop_directory ();
 	
-	desktop_directory_uri = gnome_vfs_get_uri_from_local_path (desktop_directory_path);
-	g_free (desktop_directory_path);
-	window->affect_desktop_on_next_location_change = TRUE;
-	nautilus_window_go_to (NAUTILUS_WINDOW (window), desktop_directory_uri);
-	g_free (desktop_directory_uri);
+	NAUTILUS_SPATIAL_WINDOW (window)->affect_spatial_window_on_next_location_change = TRUE;
+	nautilus_window_go_to (NAUTILUS_WINDOW (window), EEL_DESKTOP_URI);
+}
+
+static void
+nautilus_desktop_window_screen_size_changed (GdkScreen             *screen,
+					     NautilusDesktopWindow *window)
+{
+	int width_request, height_request;
+
+	width_request = gdk_screen_get_width (screen);
+	height_request = gdk_screen_get_height (screen);
+	
+	g_object_set (window,
+		      "width_request", width_request,
+		      "height_request", height_request,
+		      NULL);
 }
 
 NautilusDesktopWindow *
@@ -265,6 +282,10 @@ unrealize (GtkWidget *widget)
 	gdk_property_delete (root_window,
 			     gdk_atom_intern ("NAUTILUS_DESKTOP_WINDOW_ID", TRUE));
 
+	g_signal_handlers_disconnect_by_func (gtk_window_get_screen (GTK_WINDOW (window)),
+					      G_CALLBACK (nautilus_desktop_window_screen_size_changed),
+					      window);
+		
 	GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
 }
 
@@ -319,6 +340,9 @@ realize (GtkWidget *widget)
 	set_wmspec_desktop_hint (widget->window);
 
 	set_desktop_window_id (window, widget->window);
+
+	g_signal_connect (gtk_window_get_screen (GTK_WINDOW (window)), "size_changed",
+			  G_CALLBACK (nautilus_desktop_window_screen_size_changed), window);
 }
 
 static void
@@ -329,6 +353,23 @@ real_add_current_location_to_history_list (NautilusWindow *window)
 	 */
 }
 
+static char *
+real_get_title (NautilusWindow *window)
+{
+	return g_strdup (_("Desktop"));
+}
+
+static void
+real_merge_menus (NautilusWindow *window)
+{
+	EEL_CALL_PARENT (NAUTILUS_WINDOW_CLASS, merge_menus, (window));
+
+	nautilus_bonobo_set_hidden (window->details->shell_ui,
+				    STATUS_BAR_PATH, TRUE);
+	nautilus_bonobo_set_hidden (window->details->shell_ui,
+				    MENU_BAR_PATH, TRUE);
+}
+
 static void
 nautilus_desktop_window_class_init (NautilusDesktopWindowClass *class)
 {
@@ -339,6 +380,12 @@ nautilus_desktop_window_class_init (NautilusDesktopWindowClass *class)
 
 	GTK_WIDGET_CLASS (class)->map = map;
 
+	NAUTILUS_WINDOW_CLASS (class)->window_type = Nautilus_WINDOW_DESKTOP;
+
 	NAUTILUS_WINDOW_CLASS (class)->add_current_location_to_history_list 
 		= real_add_current_location_to_history_list;
+	NAUTILUS_WINDOW_CLASS (class)->merge_menus 
+		= real_merge_menus;
+	NAUTILUS_WINDOW_CLASS (class)->get_title 
+		= real_get_title;
 }
