@@ -90,6 +90,7 @@ struct _NautilusSpatialWindowDetails {
 	
 	GtkWidget *content_box;
 	GtkWidget *location_button;
+	GtkWidget *location_label;
 	GtkWidget *location_statusbar;
 
 	GnomeVFSURI *location;
@@ -262,13 +263,33 @@ nautilus_spatial_window_save_scroll_position (NautilusSpatialWindow *window)
 	g_free (scroll_string);
 }
 
+void
+nautilus_spatial_window_save_show_hidden_files_mode (NautilusSpatialWindow *window)
+{
+	char *show_hidden_file_setting;
+	Nautilus_ShowHiddenFilesMode mode;
+
+	mode = NAUTILUS_WINDOW (window)->details->show_hidden_files_mode;
+	if (mode != Nautilus_SHOW_HIDDEN_FILES_DEFAULT) {
+		if (mode == Nautilus_SHOW_HIDDEN_FILES_ENABLE) {
+			show_hidden_file_setting = "1";
+		} else {
+			show_hidden_file_setting = "0";
+		}
+		nautilus_file_set_metadata (NAUTILUS_WINDOW (window)->details->viewed_file,
+			 		    NAUTILUS_METADATA_KEY_WINDOW_SHOW_HIDDEN_FILES,
+				    	    NULL,
+				    	    show_hidden_file_setting);
+	} 
+}
+
 static void
 nautilus_spatial_window_show (GtkWidget *widget)
 {	
 	NautilusSpatialWindow *window;
 
 	window = NAUTILUS_SPATIAL_WINDOW (widget);
-
+	
 	GTK_WIDGET_CLASS (parent_class)->show (widget);
 }
 
@@ -280,6 +301,14 @@ file_menu_close_parent_windows_callback (BonoboUIComponent *component,
 	nautilus_application_close_parent_windows (NAUTILUS_SPATIAL_WINDOW (user_data));
 }
 
+static void
+file_menu_close_all_windows_callback (BonoboUIComponent *component, 
+					 gpointer user_data, 
+					 const char *verb)
+{
+	nautilus_application_close_all_spatial_windows ();
+}
+
 static void
 go_up_close_current_window_callback (BonoboUIComponent *component, 
 				     gpointer user_data, 
@@ -320,6 +349,7 @@ real_merge_menus (NautilusWindow *nautilus_window)
 	BonoboControl *control;
 	BonoboUIVerb verbs [] = {
 		BONOBO_UI_VERB ("Close Parent Folders", file_menu_close_parent_windows_callback),
+		BONOBO_UI_VERB ("Close All Folders", file_menu_close_all_windows_callback),
 		BONOBO_UI_VERB ("UpCloseCurrent", go_up_close_current_window_callback),
 		BONOBO_UI_VERB_END
 	};
@@ -360,6 +390,7 @@ real_window_close (NautilusWindow *window)
 {
 	nautilus_spatial_window_save_geometry (NAUTILUS_SPATIAL_WINDOW (window));
 	nautilus_spatial_window_save_scroll_position (NAUTILUS_SPATIAL_WINDOW (window));
+	nautilus_spatial_window_save_show_hidden_files_mode (NAUTILUS_SPATIAL_WINDOW (window));
 }
 
 static void 
@@ -406,10 +437,39 @@ location_menu_item_activated_callback (GtkWidget *menu_item,
 {
 	GnomeVFSURI *uri;
 	char *location;
+	GdkEvent *event;
 
 	uri = g_object_get_data (G_OBJECT (menu_item), "uri");
 	location = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
-	nautilus_window_go_to (NAUTILUS_WINDOW (window), location);
+	event = gtk_get_current_event();
+
+	if (!gnome_vfs_uri_equal (uri, window->details->location))
+	{
+		gboolean close_behind;
+		GList *selection;
+		GnomeVFSURI *child_uri;
+
+		close_behind = FALSE;
+		selection = NULL;
+		child_uri = g_object_get_data (G_OBJECT(menu_item), "child_uri");
+		if (child_uri != NULL) {
+			char *child_location;
+			child_location = gnome_vfs_uri_to_string (child_uri, GNOME_VFS_URI_HIDE_NONE);
+			selection = g_list_prepend (NULL, child_location);
+		}
+		if (event != NULL && ((GdkEventAny *) event)->type == GDK_BUTTON_RELEASE &&
+		   (((GdkEventButton *) event)->button == 2 ||
+		   (((GdkEventButton *) event)->state & GDK_SHIFT_MASK) != 0))
+		{
+			close_behind = TRUE;
+		}
+		nautilus_window_open_location_with_selection (NAUTILUS_WINDOW (window), location, selection, close_behind);
+	}
+
+	if (event != NULL) {
+		gdk_event_free (event);
+	}
+
 	g_free (location);
 	
 }
@@ -452,28 +512,37 @@ menu_popup_pos (GtkMenu   *menu,
 static void
 location_button_clicked_callback (GtkWidget *widget, NautilusSpatialWindow *window)
 {
-	GtkWidget *popup, *menu_item;
+	GtkWidget *popup, *menu_item, *first_item;
 	GnomeVFSURI *uri;
+	GnomeVFSURI *child_uri;
 	char *name;
 	GMainLoop *loop;
 
+	
 	g_return_if_fail (window->details->location != NULL);
 
 	popup = gtk_menu_new ();
-	
+	first_item = NULL;
 	uri = gnome_vfs_uri_ref (window->details->location);
+	child_uri = NULL;
 	while (uri != NULL) {
 		name = nautilus_get_uri_shortname_for_display (uri);
 		menu_item = gtk_image_menu_item_new_with_label (name);
+		if (first_item == NULL) {
+			first_item = menu_item;
+		}
+		
 		g_free (name);
 		gtk_widget_show (menu_item);
 		g_signal_connect (menu_item, "activate",
 				  G_CALLBACK (location_menu_item_activated_callback),
 				  window);
 		g_object_set_data_full (G_OBJECT (menu_item), "uri", uri, (GDestroyNotify)gnome_vfs_uri_unref);
+		g_object_set_data_full (G_OBJECT (menu_item), "child_uri", child_uri, (GDestroyNotify)gnome_vfs_uri_unref);
 
 		gtk_menu_shell_prepend (GTK_MENU_SHELL (popup), menu_item);
 
+		child_uri = gnome_vfs_uri_ref (uri);
 		uri = gnome_vfs_uri_get_parent (uri);
 	}
 	gtk_menu_set_screen (GTK_MENU (popup), gtk_widget_get_screen (widget));
@@ -486,6 +555,7 @@ location_button_clicked_callback (GtkWidget *widget, NautilusSpatialWindow *wind
 
 	gtk_grab_add (popup);
 	gtk_menu_popup (GTK_MENU (popup), NULL, NULL, menu_popup_pos, widget, 1, GDK_CURRENT_TIME);
+	gtk_menu_shell_select_item (GTK_MENU_SHELL (popup), first_item);
 	g_main_loop_run (loop);
 	gtk_grab_remove (popup);
 	g_main_loop_unref (loop);
@@ -505,13 +575,13 @@ nautilus_spatial_window_set_location_button  (NautilusSpatialWindow *window,
 	}
 	if (uri != NULL) {
 		name = nautilus_get_uri_shortname_for_display (uri);
-		gtk_button_set_label (GTK_BUTTON (window->details->location_button),
-				      name);
+		gtk_label_set_label (GTK_LABEL (window->details->location_label),
+				     name);
 		g_free (name);
 		gtk_widget_set_sensitive (window->details->location_button, TRUE);
 	} else {
-		gtk_button_set_label (GTK_BUTTON (window->details->location_button),
-				      "");
+		gtk_label_set_label (GTK_LABEL (window->details->location_label),
+				     "");
 		gtk_widget_set_sensitive (window->details->location_button, FALSE);
 	}
 
@@ -527,6 +597,8 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 	GtkShadowType shadow_type;
 	GtkWidget *frame;
 	GtkRcStyle *rc_style;
+	GtkWidget *arrow;
+	GtkWidget *hbox;
 
 	window->details = g_new0 (NautilusSpatialWindowDetails, 1);
 	window->affect_spatial_window_on_next_location_change = TRUE;
@@ -543,7 +615,7 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (window->details->location_statusbar), 
 					   FALSE);
 
-	window->details->location_button = gtk_button_new_with_label ("");
+	window->details->location_button = gtk_button_new ();
 	gtk_button_set_relief (GTK_BUTTON (window->details->location_button),
 			       GTK_RELIEF_NONE);
 	rc_style = gtk_widget_get_modifier_style (window->details->location_button);
@@ -554,6 +626,20 @@ nautilus_spatial_window_instance_init (NautilusSpatialWindow *window)
 
 	gtk_widget_show (window->details->location_button);
 
+	hbox = gtk_hbox_new (FALSE, 3);
+	gtk_container_add (GTK_CONTAINER (window->details->location_button), 
+			   hbox);
+	gtk_widget_show (hbox);
+	
+	window->details->location_label = gtk_label_new ("");
+	gtk_box_pack_start (GTK_BOX (hbox), window->details->location_label,
+			    FALSE, FALSE, 0);
+	gtk_widget_show (window->details->location_label);
+	
+	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_NONE);
+	gtk_box_pack_start (GTK_BOX (hbox), arrow, FALSE, FALSE, 0);
+	gtk_widget_show (arrow);
+
 	frame = gtk_frame_new (NULL);
 	gtk_widget_style_get (GTK_WIDGET (window->details->location_statusbar), 
 			      "shadow_type", &shadow_type, NULL);
