@@ -44,11 +44,11 @@
 #include <eel/eel-debug.h>
 #include <eel/eel-gdk-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
-#include <eel/eel-generous-bin.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
 #include <eel/eel-string.h>
+#include <eel/eel-vfs-extensions.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
@@ -76,6 +76,7 @@
 #include <libnautilus-private/nautilus-mime-actions.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
 #include <libnautilus-private/nautilus-sidebar-functions.h>
+#include <libnautilus-private/nautilus-view-query.h>
 #include <libnautilus/nautilus-bonobo-ui.h>
 #include <libnautilus/nautilus-clipboard.h>
 #include <libnautilus/nautilus-undo.h>
@@ -165,6 +166,8 @@ nautilus_window_instance_init (NautilusWindow *window)
 {
 	window->details = g_new0 (NautilusWindowDetails, 1);
 
+	window->details->show_hidden_files_mode = Nautilus_SHOW_HIDDEN_FILES_DEFAULT;
+	
 	/* CORBA and Bonobo setup, which must be done before the location bar setup */
 	window->details->ui_container = bonobo_window_get_ui_container (BONOBO_WINDOW (window));
 	bonobo_object_ref (window->details->ui_container);
@@ -221,12 +224,8 @@ ui_idle_handler (gpointer data)
 	old_updating_bonobo_state = window->details->updating_bonobo_state;
 
 	if (window->details->ui_pending_initialize_menus_part_2) {
-#if !NEW_UI_COMPLETE
-		if (NAUTILUS_IS_NAVIGATION_WINDOW (window)) {
-			nautilus_navigation_window_initialize_menus_part_2 (NAUTILUS_NAVIGATION_WINDOW (window));
-		}
-#endif
-		window->details->ui_pending_initialize_menus_part_2 = FALSE;
+		EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+				 merge_menus_2, (window));
 	}
 
 	if (window->details->ui_is_frozen) {
@@ -354,11 +353,17 @@ nautilus_window_set_status (NautilusWindow *window, const char *text)
 void
 nautilus_window_go_to (NautilusWindow *window, const char *uri)
 {
-	nautilus_window_open_location (window, uri);
+	nautilus_window_open_location (window, uri, FALSE);
 }
 
 void
-nautilus_window_go_up (NautilusWindow *window)
+nautilus_window_go_to_with_selection (NautilusWindow *window, const char *uri, GList *new_selection)
+{
+	nautilus_window_open_location_with_selection (window, uri, new_selection, FALSE);
+}
+
+void
+nautilus_window_go_up (NautilusWindow *window, gboolean close_behind)
 {
 	GnomeVFSURI *current_uri;
 	GnomeVFSURI *parent_uri;
@@ -383,7 +388,7 @@ nautilus_window_go_up (NautilusWindow *window)
 
 	selection = g_list_prepend (NULL, g_strdup (window->details->location));
 	
-	nautilus_window_open_location_with_selection (window, parent_uri_string, selection);
+	nautilus_window_open_location_with_selection (window, parent_uri_string, selection, close_behind);
 	
 	g_free (parent_uri_string);
 	eel_g_list_free_deep (selection);
@@ -431,19 +436,6 @@ nautilus_window_allow_reload (NautilusWindow *window, gboolean allow)
 	nautilus_window_ui_thaw (window);
 }
 
-void
-nautilus_window_allow_burn_cd (NautilusWindow *window, gboolean allow)
-{
-        g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-
-	nautilus_window_ui_freeze (window);
-
-        nautilus_bonobo_set_hidden (window->details->shell_ui,
-				    NAUTILUS_COMMAND_BURN_CD, !allow);
-
-	nautilus_window_ui_thaw (window);
-}
-
 void
 nautilus_window_go_home (NautilusWindow *window)
 {
@@ -468,29 +460,6 @@ nautilus_window_go_home (NautilusWindow *window)
 	g_free (home_uri);
 }
 
-void
-nautilus_window_launch_cd_burner (NautilusWindow *window)	
-{
-	GError *error;
-	char *argv[] = { "nautilus-cd-burner", NULL};
-	char *text;
-
-	error = NULL;
-	if (!g_spawn_async (NULL,
-			    argv, NULL,
-			    G_SPAWN_SEARCH_PATH,
-			    NULL, NULL,
-			    NULL,
-			    &error)) {
-		text = g_strdup_printf (_("Unable to launch the cd burner application:\n%s"), error->message);
-		eel_show_error_dialog (text,
-				       _("Can't launch cd burner"),
-				       GTK_WINDOW (window));
-		g_free (text);
-		g_error_free (error);
-	}
-}
-
 void
 nautilus_window_prompt_for_location (NautilusWindow *window)
 {
@@ -562,7 +531,7 @@ static void
 set_initial_window_geometry (NautilusWindow *window)
 {
 	GdkScreen *screen;
-	guint max_width_for_screen, max_height_for_screen;
+	guint max_width_for_screen, max_height_for_screen, min_width, min_height;
 	guint default_width, default_height;
 	
 	screen = gtk_window_get_screen (GTK_WINDOW (window));
@@ -586,14 +555,22 @@ set_initial_window_geometry (NautilusWindow *window)
 	max_width_for_screen = get_max_forced_width (screen);
 	max_height_for_screen = get_max_forced_height (screen);
 
+	if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+		min_width = NAUTILUS_SPATIAL_WINDOW_MIN_WIDTH;
+		min_height = NAUTILUS_SPATIAL_WINDOW_MIN_HEIGHT;
+	} else {
+		min_width = NAUTILUS_WINDOW_MIN_WIDTH;
+		min_height = NAUTILUS_WINDOW_MIN_HEIGHT;
+	}
+		
 	gtk_widget_set_size_request (GTK_WIDGET (window), 
-				     MIN (NAUTILUS_WINDOW_MIN_WIDTH, 
+				     MIN (min_width, 
 					  max_width_for_screen),
-				     MIN (NAUTILUS_WINDOW_MIN_HEIGHT, 
+				     MIN (min_height, 
 					  max_height_for_screen));
 					  
 	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
-			 get_default_size, (window , &default_width, &default_height));
+			 get_default_size, (window, &default_width, &default_height));
 			 
 	gtk_window_set_default_size (GTK_WINDOW (window), 
 				     MIN (default_width, 
@@ -623,6 +600,12 @@ real_merge_menus (NautilusWindow *window)
 	window->details->ui_pending_initialize_menus_part_2 = TRUE;
 }
 
+static void
+real_merge_menus_2 (NautilusWindow *window)
+{
+	window->details->ui_pending_initialize_menus_part_2 = FALSE;
+}
+
 static void
 nautilus_window_constructed (NautilusWindow *window)
 {
@@ -634,7 +617,6 @@ nautilus_window_constructed (NautilusWindow *window)
 			 merge_menus, (window));
 
 	nautilus_window_allow_stop (window, FALSE);
-	nautilus_window_allow_burn_cd (window, FALSE);
 
 	/* Set up undo manager */
 	nautilus_undo_manager_attach (window->application->undo_manager, G_OBJECT (window));	
@@ -786,6 +768,9 @@ nautilus_window_close (NautilusWindow *window)
 {
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
+	EEL_CALL_METHOD (NAUTILUS_WINDOW_CLASS, window,
+			 close, (window));
+	
 	gtk_widget_destroy (GTK_WIDGET (window));
 }
 
@@ -1018,55 +1003,13 @@ nautilus_window_synch_view_as_menus (NautilusWindow *window)
 	g_free (verb_name);
 }
 
-static void
-chose_component_callback (NautilusViewIdentifier *identifier, gpointer callback_data)
-{
-	NautilusWindow *window;
-
-	window = NAUTILUS_WINDOW (callback_data);
-	if (identifier != NULL) {
-		nautilus_window_set_content_view (window, identifier);
-	}
-	
-	/* FIXME bugzilla.gnome.org 41334: There should be some global
-	 * way to signal that the file type associations have changed,
-	 * so that the places that display these lists can react. For
-	 * now, hardwire this case, which is the most obvious one by
-	 * far.
-	 */
-	nautilus_window_load_view_as_menus (window);
-}
-
-static void
-cancel_chose_component_callback (NautilusWindow *window)
-{
-	if (window->details->viewed_file != NULL) {
-		nautilus_cancel_choose_component_for_file (window->details->viewed_file,
-							   chose_component_callback, 
-							   window);
-	}
-}
-
-void
-nautilus_window_show_view_as_dialog (NautilusWindow *window)
-{
-	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
-
-	/* Call back when the user chose the component. */
-	cancel_chose_component_callback (window);
-	nautilus_choose_component_for_file (window->details->viewed_file,
-					    GTK_WINDOW (window), 
-					    chose_component_callback, 
-					    window);
-}
-
 static void
 refresh_stored_viewers (NautilusWindow *window)
 {
 	GList *components, *node, *viewers;
 	NautilusViewIdentifier *identifier;
 
-        components = nautilus_mime_get_short_list_components_for_file (window->details->viewed_file);
+        components = nautilus_view_query_get_components_for_file (window->details->viewed_file);
 	viewers = NULL;
         for (node = components; node != NULL; node = node->next) {
         	identifier = nautilus_view_identifier_new_from_content_view (node->data);
@@ -1164,28 +1107,33 @@ static char *
 compute_default_title (const char *text_uri)
 {
 	NautilusFile *file;
-	char *title;
+	GnomeVFSURI *uri;
+	char *title, *displayname;
+	const char *hostname;
 
-	if (text_uri == NULL) {
-		title = g_strdup ("");
-	} else if (strcmp (text_uri, "computer://") == 0 ||
-		   strcmp (text_uri, "computer:///") == 0) {
-		title = g_strdup (_("Computer"));
-	} else if (strcmp (text_uri, "network://") == 0 ||
-		   strcmp (text_uri, "network:///") == 0) {
-		title = g_strdup (_("Network"));
-	} else if (strcmp (text_uri, "fonts://") == 0 ||
-		   strcmp (text_uri, "fonts:///") == 0) {
-		title = g_strdup (_("Fonts"));
-	} else if (strcmp (text_uri, "burn://") == 0 ||
-		   strcmp (text_uri, "burn:///") == 0) {
-		title = g_strdup (_("CD Creator"));
-	} else {
+	hostname = NULL;
+
+	if (text_uri) {
 		file = nautilus_file_get (text_uri);
-		title = nautilus_file_get_display_name (file);
+		uri = gnome_vfs_uri_new (text_uri);
+		if (uri && !gnome_vfs_uri_is_local (uri)) {
+			hostname = gnome_vfs_uri_get_host_name (uri);
+		}
+		displayname = nautilus_file_get_display_name (file);
+		if (hostname) {
+			title = g_strdup_printf (_("%s on %s"), displayname, hostname);
+			g_free (displayname);
+		} else {
+			title = displayname;
+		}
+		if (uri) {
+			gnome_vfs_uri_unref (uri);
+		}
 		nautilus_file_unref (file);
+	} else {
+		title = g_strdup ("");
 	}
-
+	
 	return title;
 }
 
@@ -1389,14 +1337,9 @@ nautilus_window_show (GtkWidget *widget)
 
 	window = NAUTILUS_WINDOW (widget);
 
+
 	GTK_WIDGET_CLASS (parent_class)->show (widget);
-
-	if (eel_preferences_get_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR)) {
-		nautilus_window_show_status_bar (window);
-	} else {
-		nautilus_window_hide_status_bar (window);
-	}
-
+	
 	nautilus_window_ui_update (window);
 }
 
@@ -1421,15 +1364,21 @@ nautilus_window_set_viewed_file (NautilusWindow *window,
 	nautilus_file_ref (file);
 
 	cancel_view_as_callback (window);
-	cancel_chose_component_callback (window);
 
 	if (window->details->viewed_file != NULL) {
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			nautilus_file_set_has_open_window (window->details->viewed_file,
+							   FALSE);
+		}
 		nautilus_file_monitor_remove (window->details->viewed_file,
 					      window);
 	}
 
 	if (file != NULL) {
-		attributes = NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME;
+		if (NAUTILUS_IS_SPATIAL_WINDOW (window)) {
+			nautilus_file_set_has_open_window (file, TRUE);
+		}
+		attributes = NAUTILUS_FILE_ATTRIBUTE_DISPLAY_NAME | NAUTILUS_FILE_ATTRIBUTE_SLOW_MIME_TYPE;
 		nautilus_file_monitor_add (file, window, attributes);
 	}
 
@@ -1605,6 +1554,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	class->get_title = real_get_title;
 	class->set_title = real_set_title;
 	class->merge_menus = real_merge_menus;
+	class->merge_menus_2 = real_merge_menus_2;
 	class->set_content_view_widget = real_set_content_view_widget;
 	class->load_view_as_menu = real_load_view_as_menu;
 	
