@@ -110,9 +110,6 @@ struct NautilusWindow {
 
         /* All views */
         GList *views;
-
-        /* Window showed state (for saved_window_positions) */
-        NautilusWindowShowState show_state;
 };
 
 GType            nautilus_window_get_type             (void);
@@ -122,6 +119,9 @@ void             nautilus_window_close                (NautilusWindow    *window
 char *           nautilus_window_get_location         (NautilusWindow    *window);
 void             nautilus_window_go_to                (NautilusWindow    *window,
                                                        const char        *location);
+void             nautilus_window_go_to_with_selection (NautilusWindow    *window,
+                                                       const char        *location,
+                                                       GList             *new_selection);
 void             nautilus_window_go_home              (NautilusWindow    *window);
 void             nautilus_window_go_up                (NautilusWindow    *window,
                                                        gboolean           close_behind);
